@@ -54,11 +54,6 @@ typedef enum {
     S2N_LIB_OWNED,
 } s2n_cert_ownership;
 
-typedef enum {
-    S2N_SERIALIZED_CONN_NONE = 0,
-    S2N_SERIALIZED_CONN_V1 = 1
-} s2n_serialization_version;
-
 struct s2n_config {
     unsigned use_tickets : 1;
 
@@ -110,6 +105,10 @@ struct s2n_config {
     /* TLS1.3 can be dangerous with kTLS. Require it to be explicitly enabled. */
     unsigned ktls_tls13_enabled : 1;
 
+    unsigned custom_blinding_set : 1;
+
+    unsigned ticket_forward_secrecy : 1;
+
     struct s2n_dh_params *dhparams;
     /* Needed until we can deprecate s2n_config_add_cert_chain_and_key. This is
      * used to release memory allocated only in the deprecated API that the application 
@@ -128,6 +127,8 @@ struct s2n_config {
     s2n_client_hello_fn *client_hello_cb;
     s2n_client_hello_cb_mode client_hello_cb_mode;
 
+    uint32_t max_blinding;
+
     void *client_hello_cb_ctx;
 
     uint64_t session_state_lifetime_in_nanos;
@@ -230,6 +231,9 @@ struct s2n_config {
      * the new feature to their entire fleet.)
      */
     s2n_serialization_version serialized_connection_version;
+
+    /* List of certificate authorities supported */
+    struct s2n_blob cert_authorities;
 };
 
 S2N_CLEANUP_RESULT s2n_config_ptr_free(struct s2n_config **config);
@@ -251,6 +255,3 @@ S2N_RESULT s2n_config_wall_clock(struct s2n_config *config, uint64_t *output);
  * in `security_policy` */
 S2N_RESULT s2n_config_validate_loaded_certificates(const struct s2n_config *config,
         const struct s2n_security_policy *security_policy);
-
-/* APIs that will be moved to s2n.h when the serialized connection feature is released */
-int s2n_config_set_serialized_connection_version(struct s2n_config *config, s2n_serialization_version version);
