@@ -119,7 +119,7 @@
 #define TLS_PSK_DHE_KE_MODE 1
 
 /**
- *= https://tools.ietf.org/rfc/rfc9001.txt#8.2
+ *= https://www.rfc-editor.org/rfc/rfc9001#8.2
  *#   enum {
  *#      quic_transport_parameters(0x39), (65535)
  *#   } ExtensionType;
@@ -157,7 +157,7 @@
 #define TLS_SIGNATURE_SCHEME_RSA_PSS_PSS_SHA512  0x080B
 
 #define TLS_SIGNATURE_SCHEME_LEN          2
-#define TLS_SIGNATURE_SCHEME_LIST_MAX_LEN 64
+#define TLS_SIGNATURE_SCHEME_LIST_MAX_LEN 128
 
 /* The TLS record types we support */
 #define SSLv2_CLIENT_HELLO     1
